# ferriswheel
An API for [ferrischat](https://ferris.chat)

### As ferrischat is not yet done, this library is also a work in progress!!
Ferriswheel is an async, aiohttp-based api for [ferrischat](https://ferris.chat)! It aims to be easy to use and efficient. 
